@@ -630,10 +630,7 @@ def sample(
         else:
             kwargs["nuts"] = {"target_accept": kwargs.pop("target_accept")}
     if isinstance(trace, list):
-        raise DeprecationWarning(
-            "We have removed support for partial traces because it simplified things."
-            " Please open an issue if & why this is a problem for you."
-        )
+        raise ValueError("Please use `var_names` keyword argument for partial traces.")
 
     model = modelcontext(model)
     if not model.free_RVs:
@@ -1464,7 +1461,7 @@ def init_nuts(
         potential = quadpotential.QuadPotentialDiag(cov)
     elif init == "map":
         start = pm.find_MAP(include_transformed=True, seed=random_seed_list[0])
-        cov = pm.find_hessian(point=start)
+        cov = -pm.find_hessian(point=start, negate_output=False)
         initial_points = [start] * chains
         potential = quadpotential.QuadPotentialFull(cov)
     elif init == "adapt_full":
