@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -14,9 +14,7 @@
 # This file exists only for backward-compatibility with imports like
 # `import pymc.sampling_jax` or `from pymc import sampling_jax`.
 
-# pylint: disable=wildcard-import
-# pylint: disable=unused-wildcard-import
 import warnings
 
 warnings.warn("This module is deprecated, use pymc.sampling.jax", DeprecationWarning)
-from pymc.sampling.jax import *
+from pymc.sampling.jax import *  # noqa: E402, F403
